@@ -137,7 +137,10 @@ class Analytics:
         data, headers = oauth.access_data_and_headers(code, self.secrets)
 
         r = self._session.post(self.secrets.token_uri, data=data, headers=headers)
-        r.raise_for_status()
+        if r.is_error:
+            error = r.json()["error"]
+            raise errors.AuthenticationError(error["code"], error["message"])
+
         return Tokens.from_data(r.json())
 
     def needs_refresh(self) -> bool:
@@ -174,8 +177,12 @@ class Analytics:
         )
 
         r = self._session.post(self.secrets.token_uri, data=data, headers=headers)
-        r.raise_for_status()
-        self._tokens.update(r.json())
+        if not r.is_error:
+            self._tokens.update(r.json())
+        else:
+            log.info("Your refresh token has expired; you will need to reauthorise")
+            self._tokens = self._retrieve_tokens()
+
         self._tokens.write(self._token_path)
 
     def authorise(  # nosec B107
@@ -278,14 +285,14 @@ class Analytics:
                     not consistent.
 
             currency:
-                The currency in which financial data will be displayed
-                in. Defaults to "USD". This **must** be an ISO 4217
-                currency code.
+                The currency in which financial data will be displayed.
+                Defaults to "USD". This **must** be an ISO 4217 currency
+                code (such as USD or GBP).
             start_index:
-                The row to start pulling data. Defaults to ``1``. This
-                value one-indexed, meaning setting this to ``1`` will
-                include all rows, and setting it to ``10`` will remove
-                the first nine rows.
+                The first row of the data to include in the report.
+                Defaults to ``1``. This value one-indexed, meaning
+                setting this to ``1`` will include all rows, and
+                setting it to ``10`` will remove the first nine rows.
             include_historical_data:
                 Whether to retrieve data from dates earlier than the
                 current channel owner assumed ownership of the channel.
